<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class IntegracaoOmFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    /**
     * Retorna o código do cliente e o interlocutor da proposta do contrato.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getDadosCliente(array $params) {
        $sql = "SELECT NVL(ORC.NMPARCINTERLOCUTOR, ORC.DSINTERORCA) AS NOME_INTERLOCUTOR,
                       ORC.DSEMAIL AS EMAIL_INTERLOCUTOR,
                       CLI.CDCLIENTE
                  FROM FCT_CONTRATO CONT
                 INNER JOIN CLIENTE CLI
                    ON CLI.NRPARCNEGOCIO = CONT.NRPARCNEGOCIO
                   AND CLI.NRORG         = CONT.NRORG
                  LEFT JOIN FCT_REFEORCACONT REFE
                    ON CONT.NRSEQCONTRATO = REFE.NRSEQCONTRATO
                   AND CONT.NRORG         = REFE.NRORG
                  LEFT JOIN FCT_ORCAMENTO ORC
                    ON REFE.NRSEQORCAMENTO = ORC.NRSEQORCAMENTO
                   AND REFE.NRORG          = ORC.NRORG
                 WHERE CONT.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND CONT.NRORG         = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna os produtos da composição da proposta.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getElementosTipoProdutoProposta(array $params) {
        $sql = "SELECT DISTINCT FCT_TRABSERVORCAMENTO.IDELEMENTO, FCT_TRABSERVORCAMENTO.IDELEMENTOPAI, 
                       NVL(FCT_ITEMORCAMENTO.NMCONTRATUALITEMORCA, FCT_ITEMORCAMENTO.NMITEMORCAMENTO) AS NMPROD
                  FROM FCT_TRABSERVORCAMENTO
                  JOIN FCT_ITEMORCAMENTO
                    ON FCT_ITEMORCAMENTO.NRSEQORCAMENTO = FCT_TRABSERVORCAMENTO.NRSEQORCAMENTO
                   AND FCT_ITEMORCAMENTO.NRORG          = FCT_TRABSERVORCAMENTO.NRORG
                   AND FCT_ITEMORCAMENTO.IDELEMENTO     = FCT_TRABSERVORCAMENTO.IDELEMENTO
                 WHERE FCT_TRABSERVORCAMENTO.NRSEQORCAMENTO = :NRSEQORCAMENTO
                   AND FCT_TRABSERVORCAMENTO.NRORG          = :NRORG
                   AND FCT_TRABSERVORCAMENTO.IDTIPOELEMENTO = 'P'
                   AND FCT_TRABSERVORCAMENTO.IDESCOLHIDO    = 'S'";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    /**
     * Retorna os produtos da composição do contrato.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getElementosTipoProdutoContrato(array $params) {
        $sql = "SELECT DISTINCT TRAB.IDELEMENTO,
                       TRAB.IDELEMENTOPAI,
                       NVL(ITEM.NMCONTRATUALITEMCONT, ITEM.NMITEMCONTRATO) AS NMPROD
                  FROM FCT_TRABSERVCONTRATO TRAB
                 INNER JOIN FCT_ITEMCONTRATO ITEM
                    ON ITEM.NRSEQCONTRATO = TRAB.NRSEQCONTRATO
                   AND ITEM.NRORG         = TRAB.NRORG
                   AND ITEM.IDELEMENTO    = TRAB.IDELEMENTO
                 WHERE TRAB.NRSEQCONTRATO  = :NRSEQCONTRATO
                   AND TRAB.NRORG          = :NRORG
                   AND TRAB.IDTIPOELEMENTO = 'P'
                   AND TRAB.IDESCOLHIDO    = 'S'";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getCdservorcaToQtMin(array $params) {
        $sql = " SELECT ITEM.CDSERVORCA
                   FROM FCT_ITEMORCAMENTO ITEM
                   JOIN FCT_TIPOMEDIDASERV TIPO ON ITEM.CDTPMEDIDASERV = TIPO.CDTPMEDIDASERV
                   JOIN FCT_SERVICOORCA SERV ON ITEM.CDSERVORCA = SERV.CDSERVORCA
                  WHERE ITEM.NRORG = :NRORG
                    AND ITEM.NRSEQORCAMENTO = :NRSEQORCAMENTO
                    AND TIPO.IDQTMINIMA = 'S'
                    AND SERV.IDLICENUSOMANUT = 'L'";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getLicenManut(array $params) {
        $sql = "SELECT ITCONT.VRUNITITEMCONT AS VRUNITARIO
                  FROM FCT_ITEMCONTRATO ITCONT
                 INNER JOIN FCT_SERVICOORCA SERV
                    ON ITCONT.CDSERVORCA = SERV.CDSERVORCA
                   AND ITCONT.NRORG      = SERV.NRORG
                 WHERE ITCONT.NRSEQCONTRATO     = :NRSEQCONTRATO
                   AND ITCONT.NRORG             = :NRORG
                   AND ITCONT.NRITEMCONTRATOPAI IS NOT NULL
                   AND ITCONT.IDELEMENTO        = :IDELEMENTO
                   AND SERV.IDLICENUSOMANUT     = 'M'";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getLicenuso(array $params) {
        $sql = "SELECT ITCONT.VRUNITITEMCONT AS VRUNITARIO
                  FROM FCT_ITEMCONTRATO ITCONT
                 INNER JOIN FCT_SERVICOORCA SERV
                    ON ITCONT.CDSERVORCA = SERV.CDSERVORCA
                   AND ITCONT.NRORG      = SERV.NRORG
                 WHERE ITCONT.NRSEQCONTRATO     = :NRSEQCONTRATO
                   AND ITCONT.NRORG             = :NRORG
                   AND ITCONT.NRITEMCONTRATOPAI IS NOT NULL
                   AND ITCONT.IDELEMENTO        = :IDELEMENTO
                   AND SERV.IDLICENUSOMANUT     = 'L'";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getQuantidadeMinimaLicencaContrato(array $params) {
        $sql = "SELECT QTMEDIDAVARIAVEL
                  FROM FCT_RELACMEDIDACONTRATO
                 WHERE NRSEQCONTRATO      = :NRSEQCONTRATO
                   AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL
                   AND IDELEMENTORAIZ     = :IDELEMENTORAIZ
                   AND NRORG              = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getCdtpMedidaVariavelFromOm(array $params) {
        $sql = "SELECT DECODE(NVL(CDTPMEDIDASERV, 0), 0, CDUSUTPMEDIDASERV, CDTPMEDIDASERV) AS CDTPMEDIDAVARIAVEL
                  FROM OM_PRODUTO PROD
                 WHERE PROD.ID    = :ID
                   AND PROD.NRORG = :NRORG";
                   
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    /**
     * Retorna os menus de úlimo nível do produto da composição da proposta.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getElementosFilhosTipoMenuPorProdutoProposta(array $params) {
        $sql = "SELECT DISTINCT TRAB.IDELEMENTO,
                       TRAB.IDELEMENTOPAI
                  FROM (SELECT NRSEQORCAMENTO,
                               IDELEMENTO,
                               IDELEMENTOPAI,
                               IDESCOLHIDO,
                               IDTIPOELEMENTO,
                               NRORG
                          FROM FCT_TRABSERVORCAMENTO
                         WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                           AND NRORG          = :NRORG
                           AND IDESCOLHIDO    = 'S') TRAB
                  LEFT JOIN FCT_TRABSERVORCAMENTO FILHO
                    ON TRAB.IDELEMENTO          = FILHO.IDELEMENTOPAI
                   AND TRAB.NRSEQORCAMENTO      = FILHO.NRSEQORCAMENTO
                   AND TRAB.NRORG               = FILHO.NRORG
                 WHERE FILHO.IDELEMENTO   IS NULL
                   AND TRAB.IDTIPOELEMENTO = 'M'
                 START WITH TRAB.IDELEMENTO     = :IDELEMENTO
               CONNECT BY PRIOR TRAB.IDELEMENTO = TRAB.IDELEMENTOPAI";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getElementosFilhosTipoMenuPorProdutoContrato(array $params) {
        $sql = "SELECT DISTINCT TRAB.IDELEMENTO,
                     TRAB.IDELEMENTOPAI,
                     DECODE(TRAB.NRSEQCONTRATO, :NRSEQCONTRATO, 'S', 'N') AS IS_UPDATE,
                     DECODE(FCT_CONTRATO.NRSEQCONTRATO, :NRSEQCONTRATO,  DECODE(:SUSPENSAO, 'S', TO_CHAR(SYSDATE, 'DD/MM/YYYY') , TO_CHAR(NVL(FCT_CONTRATO.DTFINVIGENCONT, FCT_CONTRATO.DTFIMCONTRATO), 'DD/MM/YYYY')) , TO_CHAR(NVL(FCT_CONTRATO.DTFINVIGENCONT, FCT_CONTRATO.DTFIMCONTRATO), 'DD/MM/YYYY')) AS DTFINVIGENCONT,
                     TRAB.IDAPARECEPROPOSTA
                FROM (SELECT NRSEQCONTRATO,
                             IDELEMENTO,
                             IDELEMENTOPAI,
                             IDESCOLHIDO,
                             IDTIPOELEMENTO,
                             NRORG,
                             IDAPARECEPROPOSTA
                        FROM FCT_TRABSERVCONTRATO
                       WHERE NRORG         = :NRORG
                         AND IDESCOLHIDO   = 'S'
                         AND NRSEQCONTRATO IN (SELECT NRSEQCONTRATO
                                               FROM FCT_CONTRATO
                                               WHERE (IDSITUACAOCONTRATO = 'A' OR NRSEQCONTRATO = :NRSEQCONTRATO)
                                                  AND NRPARCNEGOCIO      = (SELECT NRPARCNEGOCIO
                                                                            FROM FCT_CONTRATO
                                                                            WHERE NRSEQCONTRATO = :NRSEQCONTRATO))
                ) TRAB
                 JOIN FCT_CONTRATO 
                   ON FCT_CONTRATO.NRSEQCONTRATO = TRAB.NRSEQCONTRATO
                  AND FCT_CONTRATO.NRORG = TRAB.NRORG
                WHERE TRAB.IDTIPOELEMENTO        = 'M'
                START WITH TRAB.IDELEMENTO       = :IDELEMENTO
                CONNECT BY PRIOR TRAB.IDELEMENTO = TRAB.IDELEMENTOPAI";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Verifica se o produto existe na base de dados.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function verificarExistenciaProduto(array $params) {
        $sql = "SELECT COUNT(*) AS EXISTE
                  FROM FCT_SERVICOORCA
                 WHERE NRORG          = :NRORG
                   AND IDTIPO         = 'E'
                   AND IDTIPOELEMENTO = 'P'
                   AND IDELEMENTO     = :IDELEMENTO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna o produto e seus elementos.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getElementosDoProduto(array $params) {
        $sql = "SELECT IDELEMENTO, IDTIPOELEMENTO
                  FROM FCT_SERVICOORCA
                 WHERE NRORG               = :NRORG
                   AND IDTIPO              = 'E'
                   AND IDTIPOELEMENTO      = 'M'
               CONNECT BY PRIOR IDELEMENTO = IDELEMENTOPAI
                 START WITH IDELEMENTO     = :IDELEMENTO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Insere o elemento.
     * 
     * @param mixed[] $params
     */

    public function nrcomposicao(array $params){
        $sql = "SELECT NRCOMPSERVICO
                     FROM FCT_ITCOMPSERVICO
                     WHERE IDELEMENTO = :IDELEMENTO";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function validacomposicao(array $params){
        $sql = "SELECT IT.IDELEMENTOPAI AS IDELEMENTOPAI FROM FCT_ITCOMPSERVICO IT
              LEFT JOIN FCT_SERVICOORCA EL ON  IT.IDELEMENTO = EL.IDELEMENTO  AND IT.NRORG = EL.NRORG
                WHERE NVL(IT.IDELEMENTOPAI, -1) <> NVL(EL.IDELEMENTOPAI, -1)
                  AND IT.IDELEMENTO = :IDELEMENTO";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function inserirElemento(array $params) {
        $sql = "INSERT INTO FCT_SERVICOORCA (
                    CDSERVORCA,     NMSERVORCA,         IDELEMENTO,     IDELEMENTOPAI,
                    IDTIPO,         IDTIPOELEMENTO,     IDATIVO,        NRORG,
                    NRORGINCLUSAO,  CDOPERINCLUSAO,     DTINCLUSAO,     IDORDENAELEMENTO
                )
                VALUES (
                    :CDSERVORCA,    :NMSERVORCA,        :IDELEMENTO,    :IDELEMENTOPAI,
                    :IDTIPO,        :IDTIPOELEMENTO,    :IDATIVO,       :NRORG,
                    :NRORG,         :CDOPERINCLUSAO,    SYSDATE,        :IDORDENAELEMENTO
                )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Atualiza o elemento.
     * 
     * @param mixed[] $params
     */
    public function atualizarElemento(array $params) {
        $sql = "UPDATE FCT_SERVICOORCA
                   SET NMSERVORCA       = :NMSERVORCA,
                       IDELEMENTOPAI    = :IDELEMENTOPAI,
                       IDORDENAELEMENTO = :IDORDENAELEMENTO,
                       DTULTATU         = SYSDATE,
                       CDOPERULTATU     = :CDOPERULTATU,
                       NRORGULTATU      = :NRORGULTATU
                 WHERE IDELEMENTO = :IDELEMENTO
                   AND IDTIPO     = 'E'
                   AND NRORG      = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Exclui os elementos.
     * 
     * @param string  $elementos
     * @param integer $nrorg
     */
    public function excluirElementos($elementos, $nrorg) {
        $sql = "DELETE FROM FCT_SERVICOORCA
                 WHERE IDTIPO     = 'E'
                   AND IDELEMENTO IN (".$elementos.")
                   AND NRORG      = ".$nrorg;
        
        $std = $this->connection->prepare($sql);
        $std->execute();
    }
    
    /**
     * Verifica se o sistema utiliza a integração com o OM.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function verificarUtilizaIntegracao(array $params) {
        $sql = "SELECT IDINTEGRACAOOM
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna a URL de integração com o OM.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getUrlIntegracao(array $params) {
        $sql = "SELECT URLINTEGRACAOOM
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna o período de carência da proposta.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getPeriodoCarencia(array $params) {
        $sql = "SELECT NRDIASCARENCIA
                  FROM FCT_ORCAMENTO
                 WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                   AND NRORG          = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getPeriodoVigenciaContrato(array $params) {
        $sql = "SELECT TO_CHAR(NVL(DTINIVIGENCONT, DTINICIOCONTRATO), 'DD/MM/YYYY') AS DTINIVIGENCONT,
                       TO_CHAR(NVL(DTFINVIGENCONT, DTFIMCONTRATO), 'DD/MM/YYYY') AS DTFINVIGENCONT
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna o código das composições de serviço que contém o elemento informado.
     */
    public function getComposicoesPorProduto(array $params) {
        $sql = "SELECT DISTINCT NRCOMPSERVICO
                  FROM FCT_ITCOMPSERVICO
                 WHERE IDELEMENTO = :IDELEMENTO
                   AND NRORG      = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    
    /**
     * Retorna as medições para o faturamento automático.
     */
    public function buscaMedicoesFaturaAuto(array $params) {
        $sql = "SELECT MED.NRMEDICAOFATURA,
                       MED.NRSEQCONTRATO,
                       MED.CDFILIALFATURA,
                       MED.DTINICOMPET,
                       MED.DTFINCOMPET,
                       MED.DTLIMITEAPU,
                       MED.DTVENCIMENTO,
                       MED.NRDIASVENCIMENTO,
                       MED.CDTIPOOPERFATURA,
                       MED.CDSERIENF,
                       MED.CDEMPRESA,
                       MED.CDINSCESTA,
                       MED.CDINSCMUNI
                  FROM FCT_MEDICAOFATURA MED
                 WHERE TRUNC(SYSDATE) > TRUNC(MED.DTFINCOMPET)
                   AND MED.IDSITUACAO = :IDSITUACAO
                   AND MED.NRORG      = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna os dados das propostas que foram geradas.
     */
    public function buscaParcelasGeradasAuto(array $params) {
        $sql = "SELECT FCT_FATURACONT.NRFATURACONT,  PARCNEGOCIO.NMSECUNDARIPARC, TO_CHAR(FCT_FATURACONT.DTINICOMPET, 'DD/MM/YYYY') AS DTINICOMPET,
                       TO_CHAR(FCT_FATURACONT.DTFINCOMPET, 'DD/MM/YYYY') AS DTFINCOMPET, FCT_FATURACONT.VRFALTAFATURAR
                  FROM FCT_RELACAGRUPCONTFAT
                 INNER JOIN FCT_FATURACONT
                    ON FCT_FATURACONT.NRFATURACONT = FCT_RELACAGRUPCONTFAT.NRFATURACONT 
                   AND FCT_FATURACONT.NRORG = FCT_RELACAGRUPCONTFAT.NRORG 
                 INNER JOIN PARCNEGOCIO 
                    ON PARCNEGOCIO.NRPARCNEGOCIO = FCT_FATURACONT.NRPARCFATURA
                   AND PARCNEGOCIO.NRORG = FCT_FATURACONT.NRORG
                 WHERE FCT_RELACAGRUPCONTFAT.NRMEDICAOFATURA = :NRMEDICAOFATURA
                   AND FCT_RELACAGRUPCONTFAT.NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    
    /**
     * Grava o log de apuração automatica da medição de faturamento.
     */
    public function gravaLogApuraMedAuto(array $params) {
        $sql = "INSERT INTO FCT_LOG_APURAMEDAUTO (
                    NRLOGMEDICAOAUTO, NRMEDICAOFATURA, NRSEQCONTRATO, NRFATURACONT, TXLOG,
                    NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDTIPO)
                VALUES (
                    :NRLOGMEDICAOAUTO, :NRMEDICAOFATURA, :NRSEQCONTRATO, :NRFATURACONT, :TXLOG,
                    :NRORG, 'S', SYSDATE, :NRORG, :CDOPERADOR, :IDTIPO
                )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    
    /**
     * Verifica os logs gerados para gravar no arquivo.
     */
    public function verificaLogApuraMedAuto(array $params) {
        
        $sql = "SELECT FCT_LOG_APURAMEDAUTO.NRSEQCONTRATO, FCT_CONTRATO.NRCONTRATOFCT, PARCNEGOCIO.NMSECUNDARIPARC, FCT_LOG_APURAMEDAUTO.NRMEDICAOFATURA, 
                       TO_CHAR(FCT_MEDICAOFATURA.DTINICOMPET, 'DD/MM/YYYY') AS DTINICOMPET, TO_CHAR(FCT_MEDICAOFATURA.DTFINCOMPET, 'DD/MM/YYYY') AS DTFINCOMPET,  
                       FCT_LOG_APURAMEDAUTO.NRFATURACONT, FCT_FATURACONT.VRVENCIMENTO, FCT_LOG_APURAMEDAUTO.TXLOG, 
                       TO_CHAR(FCT_LOG_APURAMEDAUTO.DTINCLUSAO, 'DD/MM/YYYY HH24:MI:SS') AS DTINCLUSAO, FCT_LOG_APURAMEDAUTO.NRORG
                  FROM FCT_LOG_APURAMEDAUTO
                  LEFT JOIN FCT_CONTRATO
                    ON FCT_CONTRATO.NRSEQCONTRATO = FCT_LOG_APURAMEDAUTO.NRSEQCONTRATO
                   AND FCT_CONTRATO.NRORG = FCT_LOG_APURAMEDAUTO.NRORG
                  LEFT JOIN PARCNEGOCIO
                    ON PARCNEGOCIO.NRPARCNEGOCIO = FCT_CONTRATO.NRPARCNEGOCIO
                   AND PARCNEGOCIO.NRORG = FCT_CONTRATO.NRORG
                  LEFT JOIN FCT_MEDICAOFATURA
                    ON FCT_MEDICAOFATURA.NRMEDICAOFATURA = FCT_LOG_APURAMEDAUTO.NRMEDICAOFATURA
                   AND FCT_MEDICAOFATURA.NRORG = FCT_LOG_APURAMEDAUTO.NRORG
                  LEFT JOIN FCT_FATURACONT
                    ON FCT_FATURACONT.NRFATURACONT = FCT_LOG_APURAMEDAUTO.NRFATURACONT
                   AND FCT_FATURACONT.NRORG = FCT_LOG_APURAMEDAUTO.NRORG
                 WHERE TRUNC(FCT_LOG_APURAMEDAUTO.DTINCLUSAO) = TRUNC(SYSDATE)
                   AND FCT_LOG_APURAMEDAUTO.NRORG = :NRORG
                   AND FCT_LOG_APURAMEDAUTO.IDTIPO = :IDTIPO
                   AND (FCT_LOG_APURAMEDAUTO.NRMEDICAOFATURA = :NRMEDICAOFATURA OR :NRMEDICAOFATURA IS NULL)
                 ORDER BY FCT_LOG_APURAMEDAUTO.DTINCLUSAO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getConfiguracoesEmail($params) {
        $sql = "SELECT DSHOSTEMAIL, DSPORTAEMAIL, DSUSUARIOEMAIL, DSSENHAEMAIL, IDSMTPSECURE
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna os dados do contrato pai
     */
    public function getDadosContratoPai(array $params) {
        $sql = "SELECT PAI.NRSEQCONTRATO,
                       TO_CHAR(NVL(PAI.DTINIVIGENCONT, PAI.DTINICIOCONTRATO), 'DD/MM/YYYY') AS DTINIVIGENCONT,
                       TO_CHAR(NVL(PAI.DTFINVIGENCONT, PAI.DTFIMCONTRATO), 'DD/MM/YYYY') AS DTFINVIGENCONT,
                       PAI.DSJUSTIFCANCRENEG
                  FROM FCT_CONTRATO CONT
                  LEFT JOIN FCT_CONTRATO PAI
                    ON CONT.NRSEQCONTRATOPAI = PAI.NRSEQCONTRATO
                   AND CONT.NRORG            = PAI.NRORG
                 WHERE CONT.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND CONT.NRORG         = :NRORG";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    /**
     * Busca os contratos que estão presentes apenas na versão anterior do contrato.
    **/
    public function getProdutosRetiradosDoContrato(array $params) {
        $sql = "SELECT DISTINCT ITCONT.IDELEMENTO,
                       NVL(ITCONT.NMCONTRATUALITEMCONT, ITCONT.NMITEMCONTRATO) AS NMPROD
                  FROM FCT_ITEMCONTRATO ITCONT
                  LEFT JOIN FCT_SERVICOORCA ELE
                    ON ITCONT.IDELEMENTO = ELE.IDELEMENTO
                   AND ITCONT.NRORG      = ELE.NRORG
                 WHERE ITCONT.NRSEQCONTRATO = :NRSEQCONTRATOPAI
                   AND ITCONT.NRORG         = :NRORG
                   AND ELE.IDTIPOELEMENTO   = 'P'
                   AND ITCONT.IDELEMENTO    IS NOT NULL
                   AND ITCONT.IDELEMENTO    NOT IN (SELECT DISTINCT IDELEMENTO
                                                      FROM FCT_ITEMCONTRATO
                                                     WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                                                       AND NRORG         = :NRORG
                                                       AND IDELEMENTO IS NOT NULL)";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    
    public function getMedicoesSemColetas(array $params) {
        $sql = "SELECT COUNT(*) AS QTD
                  FROM (
                    SELECT DISTINCT MED.DTINICOMPET,
                           MED.DTFINCOMPET,
                           MED.NRMEDICAOFATURA,
                           MED.IDSITUACAO,
                           MED.NRORG,
                           CONT.NRCONTRATOFCT,
                           PARC.NMPRINCIPALPARC
                      FROM FCT_MEDICAOFATURA MED
                      JOIN FCT_MEDVARMEDICAOFATURA MEDVAR
                        ON MED.NRMEDICAOFATURA = MEDVAR.NRMEDICAOFATURA
                       AND MED.NRORG           = MEDVAR.NRORG
                      JOIN FCT_CONTRATO CONT
                        ON MED.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                       AND MED.NRORG         = CONT.NRORG
                      JOIN PARCNEGOCIO PARC
                        ON CONT.NRPARCNEGOCIO = PARC.NRPARCNEGOCIO
                       AND CONT.NRORG         = PARC.NRORG
                     WHERE MED.IDSITUACAO IN ('1', '2')
                       AND MED.NRORG = :NRORG
                       AND (TRUNC(MED.DTFINCOMPET) - TRUNC(SYSDATE) >= 0 AND TRUNC(MED.DTFINCOMPET) - TRUNC(SYSDATE) <= :QTDIASANTEFIM) )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function excluirLogMedicoesAuto($params) {
        $sql = "DELETE FROM FCT_LOG_APURAMEDAUTO
                 WHERE IDTIPO            = :IDTIPO
                   AND TRUNC(DTINCLUSAO) = TRUNC(SYSDATE)
                   AND NRORG             = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
}

?>
